@@ -9,18 +9,9 @@ setup(
     name="aimmo-game",
     packages=find_packages(),
     include_package_data=True,
-    install_requires=[
-        "aiohttp==3.7.4",
-        "aiohttp-cors",
-        "aiohttp-wsgi",
-        "eventlet==0.31.0",
-        "python-socketio==5.0.3",
-        "docker==4.4.4",
-        "google-api-python-client==1.12.8",
-        "google-cloud-logging==2.2.0",
-        "grpcio==1.43.0",
-    ],
+    install_requires=[],
     tests_require=[
+        # TODO: These have been left here so the tests can run but they're already defined in Pipfile
         "pytest~=6.2",
         "pytest-mock",
         "pytest-asyncio==0.14.0",  # downgraded because of this issue: https://github.com/pytest-dev/pytest-asyncio/issues/209
