@@ -2,20 +2,19 @@ from __future__ import absolute_import
 
 from django.contrib import admin
 
-from .models import Avatar, Game, Worksheet
+from .models import Avatar, Game
 
 
 class GameDataAdmin(admin.ModelAdmin):
     search_fields = ["id", "owner__username", "owner__email"]
-    list_display = ["id", "owner", "game_class", "school", "worksheet", "status"]
+    list_display = ["id", "owner", "game_class", "school", "worksheet_id", "status", "creation_time", "is_archived"]
     raw_id_fields = ["owner", "main_user", "can_play", "game_class"]
     readonly_fields = ["players", "auth_token"]
 
     def players(self, obj):
-        players = "\n".join(
-            [student.new_user.first_name for student in obj.game_class.students.all()]
-        )
-        players = players.join(obj.game_class.teacher.new_user.first_name)
+        teacher_user = obj.game_class.teacher.new_user
+        players = f"{teacher_user.first_name} {teacher_user.last_name}\n"
+        players += "\n".join([student.new_user.first_name for student in obj.game_class.students.all()])
         return players
 
     def school(self, obj):
@@ -25,6 +24,15 @@ class GameDataAdmin(admin.ModelAdmin):
             return None
 
 
+def stop_game(game_admin, request, queryset):
+    for game in queryset:
+        game.status = Game.STOPPED
+        game.save()
+
+
+stop_game.short_description = "Stop selected games"
+
+
 class AvatarDataAdmin(admin.ModelAdmin):
     search_fields = ["owner__username", "owner__email"]
     list_display = ["id", "owner_name", "game_id"]
@@ -38,11 +46,7 @@ class AvatarDataAdmin(admin.ModelAdmin):
         return obj.game
 
 
-class WorksheetDataAdmin(admin.ModelAdmin):
-    search_fields = ["id", "name", "era"]
-    list_display = ["id", "name", "era"]
-
-
 admin.site.register(Game, GameDataAdmin)
 admin.site.register(Avatar, AvatarDataAdmin)
-admin.site.register(Worksheet, WorksheetDataAdmin)
+
+GameDataAdmin.actions.append(stop_game)
