@@ -6,31 +6,23 @@ from common.models import UserProfile
 from common.permissions import CanDeleteGame
 from django.contrib.auth.decorators import login_required
 from django.contrib.auth.models import User
-from django.http import Http404, HttpResponse, HttpResponseForbidden, JsonResponse, HttpResponseBadRequest
+from django.db import transaction
+from django.http import Http404, HttpResponse, HttpResponseBadRequest, HttpResponseForbidden, JsonResponse
 from django.shortcuts import get_object_or_404
+from django.utils import timezone
 from django.views.decorators.csrf import ensure_csrf_cookie
 from rest_framework import mixins, status, viewsets
 from rest_framework.authentication import BasicAuthentication, SessionAuthentication
-from rest_framework.decorators import (
-    api_view,
-    authentication_classes,
-    permission_classes,
-    action,
-)
+from rest_framework.decorators import action, api_view, authentication_classes, permission_classes
 from rest_framework.permissions import IsAuthenticated
 from rest_framework.response import Response
 from rest_framework.views import APIView
 
 from . import game_renderer
-from .avatar_creator import create_avatar_for_user
 from .exceptions import UserCannotPlayGameException
-from .models import Avatar, Game
-from .permissions import (
-    CanDeleteGameOrReadOnly,
-    CsrfExemptSessionAuthentication,
-    GameHasToken,
-)
-from .serializers import GameSerializer, GameIdsSerializer
+from .game_manager.game_manager import GameManager
+from .models import Avatar, Game, GameIdsSerializer, GameSerializer, WorksheetUsage
+from .permissions import CanDeleteGameOrReadOnly, CsrfExemptSessionAuthentication
 
 LOGGER = logging.getLogger(__name__)
 
@@ -49,7 +41,7 @@ def code(request, id):
     try:
         avatar = game.avatar_set.get(owner=request.user)
     except Avatar.DoesNotExist:
-        avatar = create_avatar_for_user(request.user, id)
+        avatar = Avatar.objects.create(game=game, owner=request.user)
 
     if request.method == "POST":
         avatar.code = request.POST["code"]
@@ -73,9 +65,22 @@ def badges(request, id):
     try:
         avatar = game.avatar_set.get(owner=request.user)
     except Avatar.DoesNotExist:
-        avatar = create_avatar_for_user(request.user, id)
+        avatar = Avatar.objects.create(game=game, owner=request.user)
     avatar_user_profile = UserProfile.objects.get(user=avatar.owner)
 
+    worksheet_usage = (
+        WorksheetUsage.objects.filter(
+            user=request.user,
+            klass=game.game_class,
+            worksheet_id=game.worksheet_id,
+        )
+        .order_by("created_at")
+        .last()
+    )
+    if worksheet_usage and not worksheet_usage.loaded_at:
+        worksheet_usage.loaded_at = timezone.now()
+        worksheet_usage.save()
+
     if request.method == "POST":
         earned_badges = request.POST["badges"]
 
@@ -94,7 +99,6 @@ def badges(request, id):
 
 class GameUsersView(APIView):
     authentication_classes = (CsrfExemptSessionAuthentication, BasicAuthentication)
-    permission_classes = (GameHasToken,)
 
     def get(self, request, id):
         game = get_object_or_404(Game, id=id)
@@ -110,12 +114,7 @@ class GameUsersView(APIView):
         return users
 
 
-class GameViewSet(
-    viewsets.GenericViewSet,
-    mixins.DestroyModelMixin,
-    mixins.RetrieveModelMixin,
-    mixins.UpdateModelMixin,
-):
+class GameViewSet(viewsets.GenericViewSet, mixins.RetrieveModelMixin, mixins.UpdateModelMixin):
     authentication_classes = (CsrfExemptSessionAuthentication, SessionAuthentication)
     queryset = Game.objects.all()
     permission_classes = (CanDeleteGameOrReadOnly,)
@@ -128,7 +127,10 @@ class GameViewSet(
             response[game.pk] = serializer.data
         return Response(response)
 
-    @action(methods=["get"], detail=False)
+    @action(
+        methods=["get"],
+        detail=False,
+    )
     def running(self, request):
         response = {
             game.pk: GameSerializer(game).data for game in Game.objects.filter(status=Game.RUNNING, is_archived=False)
@@ -143,18 +145,32 @@ class GameViewSet(
     )
     def delete_games(self, request):
         game_ids = request.data.getlist("game_ids")
-        games = (
-            Game.objects.filter(
-                pk__in=game_ids,
-                game_class__teacher__school=request.user.userprofile.teacher.school,
-                is_archived=False,
+
+        with transaction.atomic():
+            games = (
+                Game.objects.filter(
+                    pk__in=game_ids,
+                    game_class__teacher__school=request.user.userprofile.teacher.school,
+                    is_archived=False,
+                )
+                if request.user.userprofile.teacher.is_admin
+                else Game.objects.filter(pk__in=game_ids, game_class__teacher__new_user=request.user, is_archived=False)
             )
-            if request.user.userprofile.teacher.is_admin
-            else Game.objects.filter(pk__in=game_ids, game_class__teacher__new_user=request.user, is_archived=False)
-        )
-        for game in games:
-            game.is_archived = True  # mark as deleted/archived
-            game.save()
+            try:
+                game_manager = GameManager()
+                for game in games:
+                    # Shutdown the game server
+                    game_manager.delete_game_server(game_id=game.id)
+
+                    # Archive the games in the database
+                    game.is_archived = True  # mark as deleted/archived
+                    game.status = Game.STOPPED
+                    game.save()
+            except Exception as exception:
+                LOGGER.error(f"Could not delete game servers for games: {', '.join(game_ids)}")
+                # Re-raise exception so that atomic transaction reverts
+                raise exception
+
         return Response(status=status.HTTP_204_NO_CONTENT)
 
 
@@ -187,17 +203,6 @@ class GameTokenView(APIView):
     """
 
     authentication_classes = (CsrfExemptSessionAuthentication, BasicAuthentication)
-    permission_classes = (GameHasToken,)
-
-    def get(self, request, id):
-        """
-        After the initial token request, we need to check where the
-        request comes from. So for subsequent requests we verify that
-        they came from the token-holder.
-        """
-        game = get_object_or_404(Game, id=id)
-        self.check_object_permissions(self.request, game)
-        return Response(data={"token": game.auth_token})
 
     def patch(self, request, id):
         game = get_object_or_404(Game, id=id)
@@ -216,8 +221,25 @@ def watch_game(request, id):
     if not game.can_user_play(request.user):
         raise Http404
 
-    game.status = Game.RUNNING
-    game.save()
+    with transaction.atomic():
+        game: Game = Game.objects.select_for_update().get(id=game.id)
+
+        if game.status != Game.RUNNING:
+            # Create a game server for this game
+            game_manager = GameManager()
+            game_manager.create_game_server(
+                game_id=game.id,
+                game_data=GameSerializer(game).data,
+            )
+            game.status = Game.RUNNING
+            game.save()
+
+        WorksheetUsage.objects.create(
+            user=request.user,
+            klass=game.game_class,
+            worksheet_id=game.worksheet_id,
+        )
+
     return game_renderer.render_game(request, game)
 
 
